@@ -20,6 +20,8 @@ from sanic.log import LOGGING_CONFIG_DEFAULTS
 from sanic.response import text
 from sanic.router import Route
 
+from .conftest import get_port
+
 
 @pytest.fixture(autouse=True)
 def clear_app_registry():
@@ -36,18 +38,20 @@ def test_app_loop_running(app: Sanic):
     assert response.text == "pass"
 
 
-def test_create_asyncio_server(app: Sanic):
+@pytest.mark.asyncio
+def test_create_asyncio_server(app: Sanic, port: int):
     loop = asyncio.get_event_loop()
-    asyncio_srv_coro = app.create_server(return_asyncio_server=True)
+    asyncio_srv_coro = app.create_server(return_asyncio_server=True, port=port)
     assert isawaitable(asyncio_srv_coro)
     srv = loop.run_until_complete(asyncio_srv_coro)
     assert srv.is_serving() is True
 
 
-def test_asyncio_server_no_start_serving(app: Sanic):
+@pytest.mark.asyncio
+def test_asyncio_server_no_start_serving(app: Sanic, port):
     loop = asyncio.get_event_loop()
     asyncio_srv_coro = app.create_server(
-        port=43123,
+        port=port,
         return_asyncio_server=True,
         asyncio_server_kwargs=dict(start_serving=False),
     )
@@ -55,6 +59,7 @@ def test_asyncio_server_no_start_serving(app: Sanic):
     assert srv.is_serving() is False
 
 
+@pytest.mark.asyncio
 def test_asyncio_server_start_serving(app: Sanic):
     loop = asyncio.get_event_loop()
     asyncio_srv_coro = app.create_server(
@@ -72,11 +77,14 @@ def test_asyncio_server_start_serving(app: Sanic):
     # Looks like we can't easily test `serve_forever()`
 
 
-def test_create_server_main(app: Sanic, caplog):
+@pytest.mark.asyncio
+def test_create_server_main(app: Sanic, caplog, port):
     app.listener("main_process_start")(lambda *_: ...)
     loop = asyncio.get_event_loop()
     with caplog.at_level(logging.INFO):
-        asyncio_srv_coro = app.create_server(return_asyncio_server=True)
+        asyncio_srv_coro = app.create_server(
+            return_asyncio_server=True, port=port
+        )
         loop.run_until_complete(asyncio_srv_coro)
     assert (
         "sanic.root",
@@ -86,10 +94,11 @@ def test_create_server_main(app: Sanic, caplog):
     ) in caplog.record_tuples
 
 
-def test_create_server_no_startup(app: Sanic):
+@pytest.mark.asyncio
+def test_create_server_no_startup(app: Sanic, port):
     loop = asyncio.get_event_loop()
     asyncio_srv_coro = app.create_server(
-        port=43124,
+        port=port,
         return_asyncio_server=True,
         asyncio_server_kwargs=dict(start_serving=False),
     )
@@ -101,11 +110,14 @@ def test_create_server_no_startup(app: Sanic):
         loop.run_until_complete(srv.start_serving())
 
 
-def test_create_server_main_convenience(app: Sanic, caplog):
+@pytest.mark.asyncio
+def test_create_server_main_convenience(app: Sanic, caplog, port):
     app.main_process_start(lambda *_: ...)
     loop = asyncio.get_event_loop()
     with caplog.at_level(logging.INFO):
-        asyncio_srv_coro = app.create_server(return_asyncio_server=True)
+        asyncio_srv_coro = app.create_server(
+            return_asyncio_server=True, port=port
+        )
         loop.run_until_complete(asyncio_srv_coro)
     assert (
         "sanic.root",
@@ -125,10 +137,9 @@ def test_app_loop_not_running(app: Sanic):
     )
 
 
-def test_app_run_raise_type_error(app: Sanic):
-
+def test_app_run_raise_type_error(app: Sanic, port):
     with pytest.raises(TypeError) as excinfo:
-        app.run(loop="loop")
+        app.run(loop="loop", port=port)
 
     assert str(excinfo.value) == (
         "loop is not a valid argument. To use an existing loop, "
@@ -139,7 +150,6 @@ def test_app_run_raise_type_error(app: Sanic):
 
 
 def test_app_route_raise_value_error(app: Sanic):
-
     with pytest.raises(ValueError) as excinfo:
 
         @app.route("/test")
@@ -221,7 +231,6 @@ def test_app_websocket_parameters(websocket_protocol_mock, app: Sanic):
 
 
 def test_handle_request_with_nested_exception(app: Sanic, monkeypatch):
-
     err_msg = "Mock Exception"
 
     def mock_error_handler_response(*args, **kwargs):
@@ -241,7 +250,6 @@ def test_handle_request_with_nested_exception(app: Sanic, monkeypatch):
 
 
 def test_handle_request_with_nested_exception_debug(app: Sanic, monkeypatch):
-
     err_msg = "Mock Exception"
 
     def mock_error_handler_response(*args, **kwargs):
@@ -291,7 +299,7 @@ def test_handle_request_with_nested_sanic_exception(
 
 
 def test_app_name_required():
-    with pytest.raises(SanicException):
+    with pytest.raises(TypeError):
         Sanic()
 
 
@@ -425,8 +433,7 @@ def test_bad_custom_config():
 
 
 def test_custom_config():
-    class CustomConfig(Config):
-        ...
+    class CustomConfig(Config): ...
 
     config = CustomConfig()
     app = Sanic("custom", config=config)
@@ -435,8 +442,7 @@ def test_custom_config():
 
 
 def test_custom_context():
-    class CustomContext:
-        ...
+    class CustomContext: ...
 
     ctx = CustomContext()
     app = Sanic("custom", ctx=ctx)
@@ -446,7 +452,7 @@ def test_custom_context():
 
 @pytest.mark.parametrize("use", (False, True))
 def test_uvloop_config(app: Sanic, monkeypatch, use):
-    @app.get("/test")
+    @app.get("/test", name="test")
     def handler(request):
         return text("ok")
 
@@ -470,6 +476,7 @@ def test_uvloop_config(app: Sanic, monkeypatch, use):
         try_use_uvloop.assert_not_called()
 
 
+@pytest.mark.asyncio
 def test_uvloop_cannot_never_called_with_create_server(caplog, monkeypatch):
     apps = (Sanic("default-uvloop"), Sanic("no-uvloop"), Sanic("yes-uvloop"))
 
@@ -486,6 +493,7 @@ def test_uvloop_cannot_never_called_with_create_server(caplog, monkeypatch):
             srv_coro = app.create_server(
                 return_asyncio_server=True,
                 asyncio_server_kwargs=dict(start_serving=False),
+                port=get_port(),
             )
             loop.run_until_complete(srv_coro)
 
@@ -506,6 +514,7 @@ def test_uvloop_cannot_never_called_with_create_server(caplog, monkeypatch):
     assert counter[(logging.WARNING, message)] == modified
 
 
+@pytest.mark.asyncio
 def test_multiple_uvloop_configs_display_warning(caplog):
     Sanic._uvloop_setting = None  # Reset the setting (changed in prev tests)
 
@@ -523,6 +532,7 @@ def test_multiple_uvloop_configs_display_warning(caplog):
             srv_coro = app.create_server(
                 return_asyncio_server=True,
                 asyncio_server_kwargs=dict(start_serving=False),
+                port=get_port(),
             )
             srv = loop.run_until_complete(srv_coro)
             loop.run_until_complete(srv.startup())
@@ -538,15 +548,15 @@ def test_multiple_uvloop_configs_display_warning(caplog):
     assert counter[(logging.WARNING, message)] == 3
 
 
-def test_cannot_run_fast_and_workers(app: Sanic):
+def test_cannot_run_fast_and_workers(app: Sanic, port):
     message = "You cannot use both fast=True and workers=X"
     with pytest.raises(RuntimeError, match=message):
-        app.run(fast=True, workers=4)
+        app.run(fast=True, workers=4, port=port)
 
 
-def test_no_workers(app: Sanic):
+def test_no_workers(app: Sanic, port):
     with pytest.raises(RuntimeError, match="Cannot serve with no workers"):
-        app.run(workers=0)
+        app.run(workers=0, port=port)
 
 
 @pytest.mark.parametrize(
@@ -558,28 +568,13 @@ def test_no_workers(app: Sanic):
     ),
 )
 def test_cannot_run_single_process_and_workers_or_auto_reload(
-    app: Sanic, extra
+    app: Sanic, extra, port
 ):
     message = (
         "Single process cannot be run with multiple workers or auto-reload"
     )
     with pytest.raises(RuntimeError, match=message):
-        app.run(single_process=True, **extra)
-
-
-def test_cannot_run_single_process_and_legacy(app: Sanic):
-    message = "Cannot run single process and legacy mode"
-    with pytest.raises(RuntimeError, match=message):
-        app.run(single_process=True, legacy=True)
-
-
-def test_cannot_run_without_sys_signals_with_workers(app: Sanic):
-    message = (
-        "Cannot run Sanic.serve with register_sys_signals=False. "
-        "Use either Sanic.serve_single or Sanic.serve_legacy."
-    )
-    with pytest.raises(RuntimeError, match=message):
-        app.run(register_sys_signals=False, single_process=False, legacy=False)
+        app.run(single_process=True, port=port, **extra)
 
 
 def test_default_configure_logging():
@@ -668,3 +663,12 @@ def test_stop_trigger_terminate(app: Sanic):
 
     app.stop(unregister=False)
     app.multiplexer.terminate.assert_called_once()
+
+
+def test_refresh_pass_passthru_data_to_new_instance(app: Sanic):
+    # arrange
+    passthru = {"_inspector": 2, "config": {"TOUCHUP": 23}}
+    app = app.refresh(passthru)
+
+    assert app.inspector == 2
+    assert app.config.TOUCHUP == 23
