@@ -1,9 +1,5 @@
-import asyncio
-
 from asyncio import CancelledError
 
-import pytest
-
 from sanic import Request, Sanic, json
 
 
