@@ -1,7 +1,6 @@
 import logging
 import os
 import platform
-import sys
 
 from unittest.mock import Mock, patch
 
@@ -69,7 +68,6 @@ def test_motd_display(caplog):
     )
 
 
-@pytest.mark.skipif(sys.version_info < (3, 8), reason="Not on 3.7")
 def test_reload_dirs(app):
     app.config.LOGO = None
     app.config.MOTD = True
