@@ -9,12 +9,11 @@ from asyncio import sleep
 
 import pytest
 
-from sanic_testing.testing import HOST, PORT
+from sanic_testing.testing import HOST
 
 from sanic import Blueprint, text
 from sanic.compat import use_context
 from sanic.log import logger
-from sanic.server.socket import configure_socket
 
 
 @pytest.mark.skipif(
@@ -26,7 +25,7 @@ from sanic.server.socket import configure_socket
     sys.platform not in ("linux", "darwin"),
     reason="This test requires fork context",
 )
-def test_multiprocessing(app):
+def test_multiprocessing(app, port):
     """Tests that the number of children we produce is correct"""
     # Selects a number at random so we can spot check
     num_workers = random.choice(range(2, multiprocessing.cpu_count() * 2 + 1))
@@ -44,101 +43,11 @@ def test_multiprocessing(app):
     signal.signal(signal.SIGALRM, stop_on_alarm)
     signal.alarm(2)
     with use_context("fork"):
-        app.run(HOST, 4120, workers=num_workers, debug=True)
+        app.run(HOST, port, workers=num_workers, debug=True)
 
     assert len(process_list) == num_workers + 1
 
 
-@pytest.mark.skipif(
-    not hasattr(signal, "SIGALRM"),
-    reason="SIGALRM is not implemented for this platform, we have to come "
-    "up with another timeout strategy to test these",
-)
-def test_multiprocessing_legacy(app):
-    """Tests that the number of children we produce is correct"""
-    # Selects a number at random so we can spot check
-    num_workers = random.choice(range(2, multiprocessing.cpu_count() * 2 + 1))
-    process_list = set()
-
-    @app.after_server_start
-    async def shutdown(app):
-        await sleep(2.1)
-        app.stop()
-
-    def stop_on_alarm(*args):
-        for process in multiprocessing.active_children():
-            process_list.add(process.pid)
-
-    signal.signal(signal.SIGALRM, stop_on_alarm)
-    signal.alarm(2)
-    app.run(HOST, 4121, workers=num_workers, debug=True, legacy=True)
-
-    assert len(process_list) == num_workers
-
-
-@pytest.mark.skipif(
-    not hasattr(signal, "SIGALRM"),
-    reason="SIGALRM is not implemented for this platform, we have to come "
-    "up with another timeout strategy to test these",
-)
-def test_multiprocessing_legacy_sock(app):
-    """Tests that the number of children we produce is correct"""
-    # Selects a number at random so we can spot check
-    num_workers = random.choice(range(2, multiprocessing.cpu_count() * 2 + 1))
-    process_list = set()
-
-    @app.after_server_start
-    async def shutdown(app):
-        await sleep(2.1)
-        app.stop()
-
-    def stop_on_alarm(*args):
-        for process in multiprocessing.active_children():
-            process_list.add(process.pid)
-
-    signal.signal(signal.SIGALRM, stop_on_alarm)
-    signal.alarm(2)
-    sock = configure_socket(
-        {
-            "host": HOST,
-            "port": 4121,
-            "unix": None,
-            "backlog": 100,
-        }
-    )
-    app.run(workers=num_workers, debug=True, legacy=True, sock=sock)
-    sock.close()
-
-    assert len(process_list) == num_workers
-
-
-@pytest.mark.skipif(
-    not hasattr(signal, "SIGALRM"),
-    reason="SIGALRM is not implemented for this platform, we have to come "
-    "up with another timeout strategy to test these",
-)
-def test_multiprocessing_legacy_unix(app):
-    """Tests that the number of children we produce is correct"""
-    # Selects a number at random so we can spot check
-    num_workers = random.choice(range(2, multiprocessing.cpu_count() * 2 + 1))
-    process_list = set()
-
-    @app.after_server_start
-    async def shutdown(app):
-        await sleep(2.1)
-        app.stop()
-
-    def stop_on_alarm(*args):
-        for process in multiprocessing.active_children():
-            process_list.add(process.pid)
-
-    signal.signal(signal.SIGALRM, stop_on_alarm)
-    signal.alarm(2)
-    app.run(workers=num_workers, debug=True, legacy=True, unix="./test.sock")
-
-    assert len(process_list) == num_workers
-
-
 @pytest.mark.skipif(
     not hasattr(signal, "SIGALRM"),
     reason="SIGALRM is not implemented for this platform",
@@ -147,7 +56,7 @@ def test_multiprocessing_legacy_unix(app):
     sys.platform not in ("linux", "darwin"),
     reason="This test requires fork context",
 )
-def test_multiprocessing_with_blueprint(app):
+def test_multiprocessing_with_blueprint(app: object, port) -> object:
     # Selects a number at random so we can spot check
     num_workers = random.choice(range(2, multiprocessing.cpu_count() * 2 + 1))
     process_list = set()
@@ -167,7 +76,7 @@ def test_multiprocessing_with_blueprint(app):
     bp = Blueprint("test_text")
     app.blueprint(bp)
     with use_context("fork"):
-        app.run(HOST, 4121, workers=num_workers, debug=True)
+        app.run(HOST, port, workers=num_workers, debug=True)
 
     assert len(process_list) == num_workers + 1
 
@@ -184,7 +93,7 @@ def stop(app):
 
 # Multiprocessing on Windows requires app to be able to be pickled
 @pytest.mark.parametrize("protocol", [3, 4])
-def test_pickle_app(app, protocol):
+def test_pickle_app(app, protocol, port):
     app.route("/")(handler)
     app.after_server_start(stop)
     app.router.reset()
@@ -193,11 +102,11 @@ def test_pickle_app(app, protocol):
     del app
     up_p_app = pickle.loads(p_app)
     assert up_p_app
-    up_p_app.run(single_process=True)
+    up_p_app.run(single_process=True, port=port)
 
 
 @pytest.mark.parametrize("protocol", [3, 4])
-def test_pickle_app_with_bp(app, protocol):
+def test_pickle_app_with_bp(app, protocol, port):
     bp = Blueprint("test_text")
     bp.route("/")(handler)
     bp.after_server_start(stop)
@@ -208,7 +117,7 @@ def test_pickle_app_with_bp(app, protocol):
     del app
     up_p_app = pickle.loads(p_app)
     assert up_p_app
-    up_p_app.run(single_process=True)
+    up_p_app.run(single_process=True, port=port)
 
 
 @pytest.mark.parametrize("protocol", [3, 4])
@@ -229,7 +138,7 @@ def test_pickle_app_with_static(app, protocol):
     sys.platform not in ("linux", "darwin"),
     reason="This test requires fork context",
 )
-def test_main_process_event(app, caplog):
+def test_main_process_event(app, caplog, port):
     # Selects a number at random so we can spot check
     num_workers = random.choice(range(2, multiprocessing.cpu_count() * 2 + 1))
 
@@ -253,7 +162,7 @@ def test_main_process_event(app, caplog):
 
     with use_context("fork"):
         with caplog.at_level(logging.INFO):
-            app.run(HOST, PORT, workers=num_workers)
+            app.run(HOST, port, workers=num_workers)
 
     assert (
         caplog.record_tuples.count(("sanic.root", 20, "main_process_start"))
