@@ -13,7 +13,7 @@ def test_payload_too_large_from_error_handler(app):
     def handler_exception(request, exception):
         return text("Payload Too Large from error_handler.", 413)
 
-    response = app.test_client.get("/1", gather_request=False)
+    _, response = app.test_client.get("/1", gather_request=False)
     assert response.status == 413
     assert response.text == "Payload Too Large from error_handler."
 
@@ -25,9 +25,9 @@ def test_payload_too_large_at_data_received_default(app):
     async def handler2(request):
         return text("OK")
 
-    response = app.test_client.get("/1", gather_request=False)
+    _, response = app.test_client.get("/1", gather_request=False)
     assert response.status == 413
-    assert "Payload Too Large" in response.text
+    assert "Request header" in response.text
 
 
 def test_payload_too_large_at_on_header_default(app):
@@ -38,6 +38,6 @@ def test_payload_too_large_at_on_header_default(app):
         return text("OK")
 
     data = "a" * 1000
-    response = app.test_client.post("/1", gather_request=False, data=data)
+    _, response = app.test_client.post("/1", gather_request=False, data=data)
     assert response.status == 413
-    assert "Payload Too Large" in response.text
+    assert "Request body" in response.text
