@@ -3,7 +3,7 @@ from sanic_testing.reusable import ReusableClient
 from sanic.response import json, text
 
 
-def test_no_body_requests(app):
+def test_no_body_requests(app, port):
     @app.get("/")
     async def handler(request):
         return json(
@@ -13,7 +13,7 @@ def test_no_body_requests(app):
             }
         )
 
-    client = ReusableClient(app, port=1234)
+    client = ReusableClient(app, port=port)
 
     with client:
         _, response1 = client.get("/")
@@ -24,7 +24,7 @@ def test_no_body_requests(app):
     assert response1.json["connection_id"] == response2.json["connection_id"]
 
 
-def test_json_body_requests(app):
+def test_json_body_requests(app, port):
     @app.post("/")
     async def handler(request):
         return json(
@@ -35,7 +35,7 @@ def test_json_body_requests(app):
             }
         )
 
-    client = ReusableClient(app, port=1234)
+    client = ReusableClient(app, port=port)
 
     with client:
         _, response1 = client.post("/", json={"foo": True})
@@ -47,7 +47,7 @@ def test_json_body_requests(app):
     assert response1.json["connection_id"] == response2.json["connection_id"]
 
 
-def test_streaming_body_requests(app):
+def test_streaming_body_requests(app, port):
     @app.post("/", stream=True)
     async def handler(request):
         data = [part.decode("utf-8") async for part in request.stream]
@@ -61,7 +61,7 @@ def test_streaming_body_requests(app):
 
     data = ["hello", "world"]
 
-    client = ReusableClient(app, port=1234)
+    client = ReusableClient(app, port=port)
 
     async def stream(data):
         for value in data:
@@ -77,7 +77,7 @@ def test_streaming_body_requests(app):
     assert response1.json["connection_id"] == response2.json["connection_id"]
 
 
-def test_bad_headers(app):
+def test_bad_headers(app, port):
     @app.get("/")
     async def handler(request):
         return text("")
@@ -86,7 +86,7 @@ def test_bad_headers(app):
     async def reqid(request, response):
         response.headers["x-request-id"] = request.id
 
-    client = ReusableClient(app, port=1234)
+    client = ReusableClient(app, port=port)
     bad_headers = {"bad": "bad" * 5_000}
 
     with client:
